# -*- coding: utf-8 -*-

# Vendor Library
from django.db import models
from django.contrib.auth import models as django_auth_models
from m3.db import BaseEnumerate

# Project Library
from concentrator.constants import (
    ConcentratorDelegateDocType)


class DelegatePerson(models.Model):
    """
    Физ. лицо представителя
    """

    doc_type = models.PositiveSmallIntegerField(
        choices=ConcentratorDelegateDocType.values.items(),
        verbose_name=u'Тип документа')
    delegate = models.OneToOneField('children.Delegate', null=True, blank=True)

    class Meta:
        verbose_name = u'Расширение модели Представителя'


class ChangeStatus(BaseEnumerate):
    """
    Статус изменения
    """

    WAIT = 0
    REJECT = 1
    ACCEPT = 2

    values = {
        WAIT: u'Ожидает решения',
        REJECT: u'Отказано',
        ACCEPT: u'Исполнено',
    }


class ChangeSource(BaseEnumerate):
    """Источник изменений"""

    UPDATE_APPLICATION = 0
    NEW_APPLICATION = 1

    values = {
        UPDATE_APPLICATION: u"Обновление данных заявки",
        NEW_APPLICATION: u"Создание новой заявки"
    }


class ChangeDeclaration(models.Model):
    """
    модель хранит список изменений по заявке
    """
    create = models.DateTimeField(auto_now_add=True,
                                  verbose_name=u'Время создания изменения')
    declaration = models.ForeignKey('declaration.Declaration')
    data = models.TextField(verbose_name=u'Содержимое объекта', null=True)
    state = models.SmallIntegerField(choices=ChangeStatus.get_choices(),
                                     verbose_name=u'Статус изменений',
                                     default=ChangeStatus.WAIT)
    commentary = models.CharField(max_length=250, null=True, blank=True,
                                  verbose_name=u'Комментарий')
    user = models.ForeignKey(django_auth_models.User,
                             null=True, verbose_name=u'Пользователь')
    source = models.SmallIntegerField(
        choices=ChangeSource.get_choices(),
        null=True, blank=True, default=ChangeSource.UPDATE_APPLICATION,
        verbose_name=u"Источник изменений")

    class Meta:
        verbose_name = u'Список изменений заявки с ЕПГУ'


class UpdateParams(models.Model):
    model_name = models.CharField(
        max_length=250, verbose_name=u'Наименование модели')
    field_name = models.CharField(max_length=250,
                                  verbose_name=u'Наименование поля')

    class Meta:
        verbose_name = u'Параметры для изменения данных'
        unique_together = ('model_name', 'field_name')


class DocExtraInfo(models.Model):
    """
    Информация о файлах пришедших из концентратора
    """

    declaration = models.ForeignKey('declaration.Declaration')

    code = models.CharField(max_length=350, verbose_name=u'Код')
    name = models.CharField(
        max_length=350, verbose_name=u'Имя',
        null=True, blank=True)
    description = models.CharField(
        max_length=350, null=True, blank=True, verbose_name=u'Описание')

    class Meta:
        verbose_name = u'Дополнительная информация о документах'
