# coding:utf-8
from spyne_smev.client import Client
from kinder.webservice.smev.decl_status_sync import SmevMethods, SmevLogs


class SmevClient(Client):
    """
    Перекрываем стандартный клиент spyne_smev'a
    для возможности логирования запросов в SmevLog
    """

    def log_request(self, smev_method, error=None):
        """
        Логирование запросов в SmevLogs
        :param error: Текст ошибки
        :param smev_method: наименование метода смэв
        """
        log_params = dict(
            direction=SmevMethods.OUTGOING,
            request=self.last_sent(),
            response=self.last_received(),
            smev_method=smev_method
        )
        if error:
            log_params.update(error=error)
        log = SmevLogs(**log_params)
        log.save()

    def last_sent(self):
        """
        Get last sent I{soap} message.
        :return: The last sent I{soap} message.
        :rtype: unicode
        """
        last_sent = super(SmevClient, self).last_sent()
        return last_sent.plain() if last_sent else u''

    def last_received(self):
        """
        Get last received I{soap} message.
        :return: The last received I{soap} message.
        :rtype: unicode
        """
        last_received = super(SmevClient, self).last_received()
        return last_received.plain() if last_received else u''